@@ -10,7 +10,11 @@ ggplot2::autoplot
 ##' @importFrom utils modifyList
 ##' @export
 autoplot.DrResult <- function(object, mapping, ...) {
-    mapping <- modifyList(aes_(~Dim1, ~Dim2), mapping)
+    if (missing(mapping)) {
+        mapping <- aes_(~Dim1, ~Dim2)
+    }else {
+        mapping <- modifyList(aes_(~Dim1, ~Dim2), mapping)
+    }
     ggplot(object, mapping, ...) + geom_point()
 }
 
